@@ -1,12 +1,11 @@
 import os
 import re
+from pathlib import Path
+from typing import List, Dict, Union
 
 import pytest
 import _pytest.python
 from packaging import version
-from typing import List, Dict, Union
-
-from pathlib import Path
 
 PARAMETRIZED_TEST_REGEX = re.compile(r'^.*?\[(.*)]$')
 
@@ -44,6 +43,22 @@ def _assert_equal(value, expected_value) -> None:
         assert expected_value == value
 
 
+def _file_encode(string: str) -> bytes:
+    """
+    Returns the bytes that would be in a file created using ``path.write_text(string)``.
+    See universal newlines documentation.
+    """
+    return string.replace('\n', os.linesep).encode()
+
+
+def _file_decode(data: bytes) -> str:
+    """
+    Returns the string that would be read from a file using ``path.read_text(string)``.
+    See universal newlines documentation.
+    """
+    return data.decode().replace('\r\n', '\n').replace('\r', '\n')
+
+
 class Snapshot:
     _snapshot_update = None  # type: bool
     _allow_snapshot_deletion = None  # type: bool
@@ -55,10 +70,10 @@ class Snapshot:
     def __init__(self, snapshot_update: bool, allow_snapshot_deletion: bool, snapshot_dir: Path):
         self._snapshot_update = snapshot_update
         self._allow_snapshot_deletion = allow_snapshot_deletion
+        self.snapshot_dir = snapshot_dir
         self._created_snapshots = []
         self._updated_snapshots = []
         self._snapshots_to_delete = []
-        self.snapshot_dir = snapshot_dir
 
     def __enter__(self):
         return self
@@ -120,7 +135,7 @@ class Snapshot:
         * The decoding function should decode bytes from a snapshot file into a object.
         """
         if isinstance(value, str):
-            return _assert_equal, str.encode, bytes.decode
+            return _assert_equal, _file_encode, _file_decode
         elif isinstance(value, bytes):
             return _assert_equal, lambda x: x, lambda x: x
         else:
@@ -180,6 +195,9 @@ class Snapshot:
         If pytest was run with the --snapshot-update flag, the snapshots will instead be updated.
         The test will fail if there were any changes to the snapshots.
         """
+        if not isinstance(values_by_filename, dict):
+            raise TypeError('values_by_filename must be a dictionary')
+
         snapshot_dir_path = self._snapshot_path(snapshot_dir_name)
 
         if snapshot_dir_path.is_dir():
@@ -208,12 +226,14 @@ class Snapshot:
 
         # Call assert_match to add, update, or assert equality for all snapshot files in the directory.
         for name, value in values_by_filename.items():
+            if not might_be_valid_filename(name):
+                raise ValueError('Invalid snapshot name: {}'.format(name))
             self.assert_match(value, snapshot_dir_path.joinpath(name))
 
 
 def shorten_path(path: Path) -> Path:
     """
-    Returns the path relative to the current working directory is possible. Otherwise return the path unchanged.
+    Returns the path relative to the current working directory if possible. Otherwise return the path unchanged.
     """
     try:
         return path.relative_to(os.getcwd())
@@ -234,7 +254,7 @@ def get_default_snapshot_dir(node: _pytest.python.Function) -> Path:
         test_name = node.originalname
         parametrize_match = PARAMETRIZED_TEST_REGEX.match(node.name)
         assert parametrize_match is not None, 'Expected request.node.name to be of format TEST_FUNCTION[PARAMS]'
-        parametrize_name = PARAMETRIZED_TEST_REGEX.match(node.name).group(1)
+        parametrize_name = parametrize_match.group(1)
         parametrize_name = get_valid_filename(parametrize_name)
     default_snapshot_dir = test_module_dir.join('snapshots', test_module, test_name)
     if parametrize_name:
@@ -248,4 +268,19 @@ def get_valid_filename(s: str) -> str:
     Taken from https://github.com/django/django/blob/master/django/utils/text.py
     """
     s = str(s).strip().replace(' ', '_')
-    return re.sub(r'(?u)[^-\w.]', '', s)
+    s = re.sub(r'(?u)[^-\w.]', '', s)
+    s = {'': 'empty', '.': 'dot', '..': 'dotdot'}.get(s, s)
+    return s
+
+
+def might_be_valid_filename(s: str) -> bool:
+    """
+    Returns false if the given string is definitely a path traversal and not a valid filename.
+
+    Note: This isn't secure, it just catches most accidental path traversals.
+    """
+    return not ('\\' in s or
+                '/' in s or
+                s == '..' or
+                s == '.' or
+                len(s) == 0)
